@@ -48,9 +48,8 @@ class Recipe(BaseSlapRecipe):
     """ """
 
     kumo_cloud_config = {}
-    # kumo_cloud_config.update(self.options)
+    kumo_cloud_config.update(self.options)
 
-    kumo_cloud_config['nosqltester_manager_binary'] = self.options['nosqltester_manager_binary']
     kumo_cloud_config['address'] = self.getGlobalIPv6Address()
     kumo_cloud_config['report_path'] = self.log_directory
     kumo_cloud_config['software_release_url'] = self.software_release_url
@@ -60,7 +59,9 @@ class Recipe(BaseSlapRecipe):
     kumo_cloud_config['computer_id'] = self.computer_id
     kumo_cloud_config['computer_partition_id'] = self.computer_partition_id
 
-    self.computer_partition.setConnectionDict(kumo_cloud_config)
+    kumo_cloud_connection = {}
+    kumo_cloud_connection['url'] = "http://["+kumo_cloud_config['address']+"]:5000/"
+    self.computer_partition.setConnectionDict(kumo_cloud_connection)
 
     nosqltester_manager_wrapper_template_location = pkg_resources.resource_filename(
                                              __name__, os.path.join(
@@ -110,7 +111,7 @@ class Recipe(BaseSlapRecipe):
   def run_kumo_manager(self, ipaddress=None):
     """ Runs the kumofs manager. """
     manager_config = {}
-    # manager_config.update(self.options)
+    manager_config.update(self.options)
 
     if ipaddress is None:
       manager_config['manager_address'] = "[%s]" % self.getGlobalIPv6Address()
@@ -119,9 +120,11 @@ class Recipe(BaseSlapRecipe):
     
     manager_config['manager_port'] = 19700
     manager_config['manager_log'] = os.path.join(self.log_directory, "kumo-manager.log")
-    manager_config['manager_binary'] = self.options['manager_binary']
 
-    self.computer_partition.setConnectionDict(manager_config)
+    manager_connection = {}
+    manager_connection['address'] = manager_config['manager_address']
+    manager_connection['port'] = manager_config['manager_port']
+    self.computer_partition.setConnectionDict(manager_connection)
 
     manager_wrapper_template_location = pkg_resources.resource_filename(
                                              __name__, os.path.join(
@@ -134,19 +137,18 @@ class Recipe(BaseSlapRecipe):
   def run_kumo_server(self):
     """ Runs the kumofs server. """
     server_config = {}
-    # server_config.update(self.options)
-    # server_config.update(self.parameter_dict)
+    server_config.update(self.options)
+    server_config.update(self.parameter_dict)
 
     server_config['server_address'] = "[%s]" % self.getGlobalIPv6Address()
     server_config['server_port'] = 19800
     server_config['server_listen_port'] = 19900
-    server_config['manager_address'] = self.parameter_dict['manager_address']
-    server_config['manager_port'] = self.parameter_dict['manager_port']
     server_config['server_storage'] = os.path.join(self.var_directory,"kumodb.tch")
     server_config['server_log'] = os.path.join(self.log_directory, "kumo-server.log")
-    server_config['server_binary'] = self.options['server_binary']
 
-    self.computer_partition.setConnectionDict(server_config)
+    server_connection = {}
+    server_connection['address'] = server_config['server_address']
+    self.computer_partition.setConnectionDict(server_connection)
 
     server_wrapper_template_location = pkg_resources.resource_filename(
                                              __name__, os.path.join(
@@ -159,18 +161,17 @@ class Recipe(BaseSlapRecipe):
   def run_kumo_gateway(self):
     """ Runs the kumofs gateway. """
     gateway_config = {}
-    # gateway_config.update(self.options)
-    # gateway_config.update(self.parameter_dict)
+    gateway_config.update(self.options)
+    gateway_config.update(self.parameter_dict)
 
-    gateway_config['manager_address'] = self.parameter_dict['manager_address']
-    gateway_config['manager_port'] = self.parameter_dict['manager_port']
     gateway_config['gateway_address'] = "[%s]" % self.getGlobalIPv6Address()
     gateway_config['gateway_port'] = 11411
     gateway_config['gateway_log'] = os.path.join(self.log_directory, "kumo-gateway.log")
-    gateway_config['gateway_binary'] = self.options['gateway_binary']
-    gateway_config['memstrike_binary'] = self.options['memstrike_binary']
 
-    self.computer_partition.setConnectionDict(gateway_config)
+    gateway_connection = {}
+    gateway_connection['address'] = gateway_config['gateway_address']
+    gateway_connection['port'] = gateway_config['gateway_port']
+    self.computer_partition.setConnectionDict(gateway_connection)
 
     gateway_wrapper_template_location = pkg_resources.resource_filename(
                                              __name__, os.path.join(
@@ -180,21 +181,23 @@ class Recipe(BaseSlapRecipe):
 
     return [gateway_runner_path]
 
-  def run_nosqltester(self):
+  def run_kumo_tester_easy(self):
     """ Runs the kumofs tester. """
     tester_config = {}
-    # tester_config.update(self.options)
-    # tester_config.update(self.parameter_dict)
+    tester_config.update(self.options)
+    tester_config.update(self.parameter_dict)
 
-    tester_config['host_address'] = self.parameter_dict['host_address']
     tester_config['tester_address'] = self.getGlobalIPv6Address()
     # tester_config['url'] = "http://%s:5000/" % tester_config['tester_address']
-    tester_config['start_url'] = "http://%s:5000/start" % tester_config['tester_address']
+    # tester_config['start_url'] = "http://%s:5000/start" % tester_config['tester_address']
     tester_config['report_path'] = self.log_directory
-    tester_config['binary'] = self.parameter_dict['binary']
-    tester_config['nosqltester_binary'] = self.options['nosqltester_binary']
+    tester_config['binary'] = tester_config['memstrike_binary'] + " -l " + \
+                              tester_config['gateway_address'].strip("[]") + " -p " + \
+                              tester_config['gateway_port'] + " 1000" #" -t 32 1024000"
 
-    self.computer_partition.setConnectionDict(tester_config)
+    tester_connection = {}
+    tester_connection['start_url'] = "http://%s:5000/start" % tester_config['tester_address']
+    self.computer_partition.setConnectionDict(tester_connection)
 
     tester_wrapper_template_location = pkg_resources.resource_filename(
                                              __name__, os.path.join(
